@@ -154,7 +154,7 @@ class AccelEntry( gobject.GObject ):
 				gtk.DIALOG_DESTROY_WITH_PARENT | gtk.DIALOG_MODAL,
 				gtk.MESSAGE_WARNING,
 				gtk.BUTTONS_CANCEL,
-				_("The shortcut \"%s\" cannot be used because it will become unusable to type using this key.\nPlease try with a key such as Control, Alt or Shift at the same time.\n")
+				_("The shortcut \"%s\" cannot be used because it will become impossible to type using this key.\nPlease try with a key such as Control, Alt or Shift at the same time.\n")
 				% gtk.accelerator_name(accel_keyval, accel_mods)
 			)
 			dialog.run()
@@ -192,7 +192,7 @@ class AccelEntry( gobject.GObject ):
 		self.set_accelerator_name(self.__old_value)
 
 class ColorblindPreferencesUI:
-	CB_FILTER_NO_FILTER, CB_FILTER_SELECTIVE_SATURATE_RED, CB_FILTER_SELECTIVE_SATURATE_GREEN, CB_FILTER_SELECTIVE_SATURATE_BLUE, CB_FILTER_SELECTIVE_DESSATURATE_RED, CB_FILTER_SELECTIVE_DESSATURATE_GREEN, CB_FILTER_SELECTIVE_DESSATURATE_BLUE, CB_FILTER_POSITIVE_HUE_SHIFT, CB_FILTER_NEGATIVE_HUE_SHIFT = range (9)
+	CB_FILTER_NO_FILTER, CB_FILTER_SELECTIVE_SATURATE_RED, CB_FILTER_SELECTIVE_SATURATE_GREEN, CB_FILTER_SELECTIVE_SATURATE_BLUE, CB_FILTER_SELECTIVE_DESATURATE_RED, CB_FILTER_SELECTIVE_DESATURATE_GREEN, CB_FILTER_SELECTIVE_DESATURATE_BLUE, CB_FILTER_POSITIVE_HUE_SHIFT, CB_FILTER_NEGATIVE_HUE_SHIFT = range (9)
 
 	def __init__(self, applet):
 		self.glade = gtk.glade.XML(join(colorblind.SHARED_DATA_DIR, "colorblind-prefs.glade"))
@@ -201,9 +201,9 @@ class ColorblindPreferencesUI:
 		self.radio1 = self.glade.get_widget("radio_filter_red_saturate")
 		self.radio2 = self.glade.get_widget("radio_filter_green_saturate")
 		self.radio3 = self.glade.get_widget("radio_filter_blue_saturate")
-		self.radio4 = self.glade.get_widget("radio_filter_red_dessaturate")
-		self.radio5 = self.glade.get_widget("radio_filter_green_dessaturate")
-		self.radio6 = self.glade.get_widget("radio_filter_blue_dessaturate")
+		self.radio4 = self.glade.get_widget("radio_filter_red_desaturate")
+		self.radio5 = self.glade.get_widget("radio_filter_green_desaturate")
+		self.radio6 = self.glade.get_widget("radio_filter_blue_desaturate")
 		self.radio7 = self.glade.get_widget("radio_filter_positive_hue_shift")
 		self.radio8 = self.glade.get_widget("radio_filter_negative_hue_shift")
 		self.hbox_default = self.glade.get_widget("hbox_default")
@@ -212,9 +212,9 @@ class ColorblindPreferencesUI:
 		self.combofilters.append_text (_("Selective Red Saturation"))
 		self.combofilters.append_text (_("Selective Green Saturation"))
 		self.combofilters.append_text (_("Selective Blue Saturation"))
-		self.combofilters.append_text (_("Selective Red Dessaturation"))
-		self.combofilters.append_text (_("Selective Green Dessaturation"))
-		self.combofilters.append_text (_("Selective Blue Dessaturation"))
+		self.combofilters.append_text (_("Selective Red Desaturation"))
+		self.combofilters.append_text (_("Selective Green Desaturation"))
+		self.combofilters.append_text (_("Selective Blue Desaturation"))
 		self.combofilters.append_text (_("Positive Hue Shift"))
 		self.combofilters.append_text (_("Negative Hue Shift"))
 		self.check_default_filter = self.glade.get_widget("check_default_filter")
@@ -255,11 +255,11 @@ class ColorblindPreferencesUI:
 		elif entry == self.radio3:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_BLUE)
 		elif entry == self.radio4:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_RED)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_RED)
 		elif entry == self.radio5:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_GREEN)
 		elif entry == self.radio6:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE)
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_BLUE)
 		elif entry == self.radio7:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_COLORBLIND_FILTER, self.CB_FILTER_POSITIVE_HUE_SHIFT)
 		elif entry == self.radio8:
@@ -274,12 +274,12 @@ class ColorblindPreferencesUI:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_GREEN)
 		elif i == self.CB_FILTER_SELECTIVE_SATURATE_BLUE:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_SATURATE_BLUE)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_RED:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_RED)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_GREEN)
-		elif i == self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE:
-			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESSATURATE_BLUE)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_RED:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_RED)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_GREEN:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_GREEN)
+		elif i == self.CB_FILTER_SELECTIVE_DESATURATE_BLUE:
+			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_SELECTIVE_DESATURATE_BLUE)
 		elif i == self.CB_FILTER_POSITIVE_HUE_SHIFT:
 			colorblind.GCONF_CLIENT.set_int(colorblind.GCONF_DEFAULT_FILTER, self.CB_FILTER_POSITIVE_HUE_SHIFT)
 		elif i == self.CB_FILTER_NEGATIVE_HUE_SHIFT:
