@@ -1234,6 +1234,15 @@ impl_magnifier_hide_cursor (PortableServer_Servant servant,
 	gmag_gs_hide_cursor (magnifier);
 }
 
+static void
+impl_magnifier_show_cursor (PortableServer_Servant servant,
+                            CORBA_Environment *ev)
+{
+	Magnifier *magnifier = MAGNIFIER (bonobo_object_from_servant (servant));
+
+	gmag_gs_show_cursor (magnifier);
+}
+
 static
 CORBA_boolean
 impl_magnifier_full_screen_capable (PortableServer_Servant servant,
@@ -1487,6 +1496,7 @@ magnifier_class_init (MagnifierClass *klass)
 
 	epv->fullScreenCapable = impl_magnifier_full_screen_capable;
 	epv->hideCursor = impl_magnifier_hide_cursor;
+	epv->showCursor = impl_magnifier_show_cursor;
 	epv->supportColorblindFilters =
 		impl_magnifier_support_colorblind_filters;
         epv->_set_SourceDisplay = impl_magnifier_set_source_display;
