@@ -97,6 +97,15 @@ gmag_cursor_hide (Magnifier *magnifier)
 	}
 }
 
+void
+gmag_cursor_show (Magnifier *magnifier)
+{
+	int minor, major;
+	XFixesQueryVersion(dpy, &major, &minor);
+	if (major >= 4) {
+		XFixesShowCursor (dpy, root_window);
+	}
+}
 
 gint
 gmag_cursor_init (Magnifier *magnifier, Display *dpy_conn)
